@@ -116,6 +116,11 @@ void AddAccMgrForm::eventhandle(NEvent* ev) 	//обработчик событи
 {
     if ( ev->done )
 	return;
+    NMouseEvent* mevent = (NMouseEvent*)ev;
+    if ( ev->type == NEvent::evMOUSE)
+    {
+	NForm::eventhandle(ev); //предок
+    }
     if ( ev->type == NEvent::evKB )
     {
 	ev->done = true;
