@@ -120,9 +120,9 @@ bool daily_statisticsCmpAbove( Item* stat1, Item* stat2 ) //для сортир
 //=============================================================================================
 
 
-SrvList::SrvList(Config* cfg)
+SrvList::SrvList(/*Config* cfg*/)
 {
-    this->cfg = cfg;
+//    this->cfg = cfg;
     refreshcfg();
 }
 
@@ -137,7 +137,7 @@ void SrvList::refreshcfg() //перечитать из конфига
 {
     clear(); //удаляем старые сервера (если есть)
 
-    Item* boinctui_cfg = cfg->getcfgptr();
+    Item* boinctui_cfg = gCfg->getcfgptr();
     if (boinctui_cfg == NULL)
 	return;
     std::vector<Item*> slist = boinctui_cfg->getItems("server");
@@ -193,6 +193,7 @@ Srv::Srv(const char* shost, const char* sport, const char* pwd) : TConnect(shost
     this->pwd = strdup(pwd);
     lastmsgno = 0;
     active = false;
+    loginfail = false;
     ccstatusdomneedupdate = false;
     pthread_mutex_init(&mutex, NULL);
 }
@@ -262,16 +263,17 @@ void Srv::createconnect()
     lock();
     TConnect::createconnect();
     unlock();
+    loginfail = false;
     if (hsock != -1)
-	login();
+	loginfail = login();
 }
 
 
 bool Srv::login() //авторизоваться на сервере
 {
     bool result = false;
-    if (strlen(pwd) == 0)
-	return true; //пароль не задан (считаем что логин серверу не требуется)
+//    if (strlen(pwd) == 0)
+//	return true; //пароль не задан (считаем что логин серверу не требуется)
     //получить случайную строку (nonce)
     Item* r1 = req("<auth1/>");
     if (r1 == NULL)
@@ -298,7 +300,7 @@ bool Srv::login() //авторизоваться на сервере
     //вторая фаза авторизации
     Item* r2 = req("<auth2>\n<nonce_hash>%s</nonce_hash>\n</auth2>",shash);
     kLogPrintf("login() Boinc answer ---\n%s\n", r2->toxmlstring().c_str());
-    if ( r2->findItem("authorize") != NULL ) //авторизация успешна
+    if ( r2->findItem("unauthorized") != NULL ) //авторизация неуспешна
 	result = true;
     delete r2;
     return result;
@@ -898,20 +900,23 @@ void* Srv::updatethread(void* args) //трейд опрашивающий сер
 	//get data from remote server
 	if ( me->statedom.empty() || ( (me->takt % STATE_TIME_INTERVAL) == 0 ) )
 	    me->updatestate(); //<get_state>
-	if ( me->msgdom.empty() || ( (me->takt % MSG_TIME_INTERVAL) == 0 ) )
-	    me->updatemsgs(); //<get_message_count>/<get_messages>
-	if ( me->statisticsdom.empty() || ( (me->takt % STATISTICS_TIME_INTERVAL) == 0 ) )
-	    me->updatestatistics(); //<get_statistics>
-	if ( me->dusagedom.empty() || ( (me->takt % DISKUSAGE_TIME_INTERVAL) == 0 ) )
-	    me->updatediskusage(); //<get_disk_usage>
-	if ( me->ccstatusdom.empty() || ( (me->takt % CCSTATUS_TIME_INTERVAL) == 0 ) || me->ccstatusdomneedupdate )
+	if (me->isconnected()&&(!me->loginfail)) //если нет коннекта то пропускаем прочие запросы
 	{
-	    me->updateccstatus(); //<get_cc_status>
-	    me->ccstatusdomneedupdate = false;
+	    if ( me->msgdom.empty() || ( (me->takt % MSG_TIME_INTERVAL) == 0 ) )
+		me->updatemsgs(); //<get_message_count>/<get_messages>
+	    if ( me->statisticsdom.empty() || ( (me->takt % STATISTICS_TIME_INTERVAL) == 0 ) )
+		me->updatestatistics(); //<get_statistics>
+	    if ( me->dusagedom.empty() || ( (me->takt % DISKUSAGE_TIME_INTERVAL) == 0 ) )
+		me->updatediskusage(); //<get_disk_usage>
+	    if ( me->ccstatusdom.empty() || ( (me->takt % CCSTATUS_TIME_INTERVAL) == 0 ) || me->ccstatusdomneedupdate )
+	    {
+		me->updateccstatus(); //<get_cc_status>
+		me->ccstatusdomneedupdate = false;
+	    }
+	    if (me->acctmgrinfodom.needupdate)
+		me->updateacctmgrinfo(); //ин-я по аккаунт менеджеру
 	}
-	if (me->acctmgrinfodom.needupdate)
-	    me->updateacctmgrinfo(); //ин-я по аккаунт менеджеру
-	
+	//спим 1 секунду проверяя me->ccstatusdomneedupdate
 	for (int i = 0; i < 10; i++)
 	{
 	    usleep(100000); //100 milisec
