@@ -225,16 +225,16 @@ std::string gethumanreadabletimestr(time_t time) //получить в виде
 }
 
 
-TaskWin::TaskWin(NRect rect, Config* cfg) : NSelectList(rect) 
+TaskWin::TaskWin(NRect rect/*, Config* cfg*/) : NSelectList(rect)
 {
     setselectorbgcolor(COLOR_CYAN);
     columnmask = ~0;
     taskslistmode = 0;
     taskssortmode = 1;
     //читаем опции из конфига если нет то создаем
-    if (cfg != NULL)
+    if (gCfg != NULL)
     {
-	Item* rootcfg = cfg->getcfgptr();
+	Item* rootcfg = gCfg->getcfgptr();
 	if (rootcfg != NULL)
 	{
 	    Item* column_view_mask = rootcfg->findItem("column_view_mask");
@@ -265,7 +265,7 @@ TaskWin::TaskWin(NRect rect, Config* cfg) : NSelectList(rect)
 	    taskssortmode = tasks_sort_mode->getivalue();
 	}
     }
-    this->cfg = cfg;
+//    this->cfg = cfg;
 };
 
 
@@ -279,9 +279,9 @@ TaskWin::~TaskWin()
 void TaskWin::saveopttoconfig() //сохранить маску и т.д. в дереве конфига
 {
     //пишем в конфиг
-    if (cfg != NULL)
+    if (gCfg != NULL)
     {
-	Item* rootcfg = cfg->getcfgptr();
+	Item* rootcfg = gCfg->getcfgptr();
 	if (rootcfg != NULL)
 	{
 	    Item* column_view_mask = rootcfg->findItem("column_view_mask");
@@ -300,14 +300,19 @@ void TaskWin::saveopttoconfig() //сохранить маску и т.д. в д
 
 void TaskWin::clearcontent()
 {
+    int oldindex = getstartindex();
     std::vector<void*>::iterator it;
     for (it = objects.begin(); it != objects.end(); it++) //очищаем строки ассоцииронанные с визуальными
     {
 	if ((*it) != NULL)
-	    free (*it);
+	{
+	    TaskInfo* d = (TaskInfo*)(*it);
+	    delete d;
+	}
     }
     objects.clear();
     NSelectList::clearcontent();
+    setstartindex(oldindex);
 }
 
 
@@ -491,6 +496,20 @@ void TaskWin::eventhandle(NEvent* ev) 	//обработчик событий
     if ( ev->done )
 	return;
     bool selectorvisiblebak = (selectedindex >= 0)&&(selectedindex < content.size()); //состояние селектора до
+    //одиночный или двойной клик
+    NMouseEvent* mevent = (NMouseEvent*)ev;
+    if (( ev->type == NEvent::evMOUSE ) && (mevent->cmdcode & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED)))
+    {
+	if (isinside(mevent->row, mevent->col))
+	{
+		//передвигаем слектор
+		setselectorpos(mevent->row - getabsbegrow() + startindex);
+		if (mevent->cmdcode & BUTTON1_DOUBLE_CLICKED) //даблклик
+		    putevent(new TuiEvent(evTASKINFO)); //событие для открытия raw task info
+		ev->done = true;
+	}
+    }
+    //клавиатура
     if ( ev->type == NEvent::evKB )
     {
 	ev->done = true;
@@ -510,8 +529,6 @@ void TaskWin::eventhandle(NEvent* ev) 	//обработчик событий
 	    default:
 		ev->done = false; //нет реакции на этот код
 	} //switch
-	if (ev->done) //если обработали, то нужно перерисоваться
-	    refresh();
     }
     if (ev->type == NEvent::evPROG) //прграммные
     {
@@ -547,6 +564,10 @@ void TaskWin::eventhandle(NEvent* ev) 	//обработчик событий
 	putevent(new TuiEvent(evTASKSELECTORON)); //селектор включился
     if (((selectedindex == -1)||(selectedindex == content.size()))&&(selectorvisiblebak))
 	putevent(new TuiEvent(evTASKSELECTOROFF)); //селектор выключился
+
+    if (ev->done) //если обработали, то нужно перерисоваться
+	refresh();
+
     //событие таймера
     if (ev->type == NEvent::evTIMER) //таймер
     {
